# PDFRepair-PyPDF

PDFRepair Tool using PyPDF.

## Installation

```bash
python3 setup.py install
```

### Tested Python Version

| Version        | Work? |
| -------------- | ----- |
| Python 3.11.7  | ✅    |
| Python 3.10.14 | ✅    |

## Usage

```bash
usage: pdf-repair [-h] [--compress] FILEPATH

positional arguments:
  FILEPATH        The PDF file or directory to repair.

options:
  -h, --help      show this help message and exit
  --compress, -c  Compress the PDF.
```
